==> olight-1.4.54.tgz: package/platform/web.js <==
import {trigger} from "../lib/event";
const Light = require("../lib/core");
import {parse2query} from "../lib/utils"
module.exports = {
    init(){
        document.addEventListener("deviceready", function () {
            window.LightJSBridge.onPageAppear = function(){
                trigger("viewappear")
            };
            window.LightJSBridge.onPageDisappear = function(){
                trigger("viewdisappear")
            };
            window.LightJSBridge.AppWillEnterForeground = function(){
                trigger("appappear")
            };
            window.LightJSBridge.AppDidEnterBackground = function(){
                trigger("appdisappear")
            };
            window.LightJSBridge.onScreenShot = function(data){
                trigger("screenshot",data.screenShot)
            };
            //154941 light框架支持Light.on("viewback") 
            window.LightJSBridge.pageShouldBack = function(data){
                return trigger("viewback",{
                    sync:true
                })
            };
        })
    },
    start(router,options){
        const app = new Light.Vue({
            el : options.el|| "#main",
            router
        });
    },
    navigateBack(number){
        // number = number > window.history.length ? window.history.length : number;
        window.LightJSBridge.call('native.back', { number: number }, null);
    },
    navigateTo(path,params,options){
        let distURL = `${path.url}?${parse2query(params)}`;
        if(path.type === "jsnative"){
            location.href = `gmu://jsnative?startPage=${encodeURIComponent(distURL)}&${parse2query(options)}`
        }
        if(path.type === "web"){
            if(options.replace===false||path.url.indexOf("vhost.light.com")>-1){
                location.href = `gmu://web?startPage=${encodeURIComponent(distURL)}&${parse2query(options)}`
            }else{
                if(options.history!==false){
                    location.href= `${path.url}?${parse2query(params)}`
                }else{
                    location.replace(`${path.url}?${parse2query(params)}`);
                }
            }
        }
        if(path.type === "native"){
            location.href = distURL;
        }
    },
    getCurrentFile(){
        return location.href.split(/([?#])/)[0];
    },
    ajax:require("./pure").ajax
};

==> olight-1.4.64.tgz: package/platform/web.js <==
import {trigger} from "../lib/event";
const Light = require("../lib/core");
import {parse2query,resolvePath} from "../lib/utils"
module.exports = {
    init(){
        document.addEventListener("deviceready", function () {
            window.LightJSBridge.onPageAppear = function(){
                trigger("viewappear")
            };
            window.LightJSBridge.onPageDisappear = function(){
                trigger("viewdisappear")
            };
            window.LightJSBridge.AppWillEnterForeground = function(){
                trigger("appappear")
            };
            window.LightJSBridge.AppDidEnterBackground = function(){
                trigger("appdisappear")
            };
            window.LightJSBridge.onScreenShot = function(data){
                trigger("screenshot",data.screenShot)
            };
            //154941 light框架支持Light.on("viewback") 
            window.LightJSBridge.pageShouldBack = function(data){
                return trigger("viewback",{
                    sync:true
                })
            };
        })
    },
    start(router,options){
        const app = new Light.Vue({
            el : options.el|| "#main",
            router
        });
    },
    navigateBack(number){
        // number = number > window.history.length ? window.history.length : number;
        window.LightJSBridge.call('native.back', { number: number }, null);
    },
    navigateTo(path,params,options){
        //166093【框架】优化light.navigate路由跳转时无入参的路由
        let distURL = resolvePath(path.url, params);
        if(path.type === "jsnative"){
            location.href = `gmu://jsnative?startPage=${encodeURIComponent(distURL)}&${parse2query(options)}`
        }
        if(path.type === "web"){
            if(options.replace===false||path.url.indexOf("vhost.light.com")>-1){
                location.href = `gmu://web?startPage=${encodeURIComponent(distURL)}&${parse2query(options)}`
            }else{
                if(options.history!==false){
                    location.href= resolvePath(path.url, params);
                }else{
                    location.replace(resolvePath(path.url, params));
                }
            }
        }
        if(path.type === "native"){
            location.href = distURL;
        }
        //167515 小程序olight模块支持navigate跳转区分lightweb和miniapp
        if(path.type === "lightweb") {
            path.type = options.miniappContainer || path.type;
            location.href = `gmu://${path.type}?startPage=${encodeURIComponent(distURL)}&${parse2query(options)}`
        }
    },
    getCurrentFile(){
        return location.href.split(/([#])/)[0];
    },
    ajax:require("./pure").ajax
};
